@@ -39,6 +39,7 @@
 #define  XC_LDA_C_LP96                  289  /*Liu-Parr correlation                                                  */
 #define  XC_LDA_C_CHACHIYO_MOD          307  /*Chachiyo simple 2 parameter correlation with modified scaling         */
 #define  XC_LDA_C_KARASIEV_MOD          308  /* Karasiev reparameterization of Chachiyo with modified scaling        */
+#define  XC_LDA_C_W20                   317  /*Xie, Wu, and Zhao correlation                                         */
 #define  XC_LDA_X_REL                   532  /*Relativistic exchange                                                 */
 #define  XC_LDA_XC_1D_EHWLRG_1          536  /*LDA constructed from slab-like systems of 1 electron                  */
 #define  XC_LDA_XC_1D_EHWLRG_2          537  /* LDA constructed from slab-like systems of 2 electrons                */
@@ -159,8 +160,10 @@
 #define  XC_HYB_GGA_XC_WP04             612  /* hybrid fitted to proton NMR shifts                                   */
 #define  XC_HYB_GGA_XC_CAMH_B3LYP       614  /* CAM version of B3LYP tuned for tddft                                 */
 #define  XC_HYB_GGA_XC_WHPBE0           615  /* Long-range corrected functional by Shao et al                        */
+#define  XC_HYB_GGA_XC_LC_BLYP_EA       625  /* Long-range corrected BLYP, tuned for electron affinities             */
 #define  XC_HYB_GGA_XC_LC_BOP           636  /* Long-range corrected B88 with B88OP correlation                      */
 #define  XC_HYB_GGA_XC_LC_PBEOP         637  /* Long-range corrected PBE with PBEOP correlation                      */
+#define  XC_HYB_GGA_XC_LC_BLYPR         639  /* Long-range corrected BLYP with correlation only in short-range       */
 #define  XC_HYB_GGA_XC_CAM_PBEH         681  /* CAM version of PBEH                                                  */
 #define  XC_HYB_GGA_XC_CAMY_PBEH        682  /* PBEH with Yukawa screening                                           */
 #define  XC_GGA_X_GAM                    32  /* GAM functional from Minnesota                                        */
@@ -409,6 +412,7 @@
 #define  XC_GGA_K_LGAP                  620  /*LGAP by Constantin et al                                              */
 #define  XC_GGA_X_ITYH_OPTX             622  /*short-range OPTX functional                                           */
 #define  XC_GGA_X_ITYH_PBE              623  /*short-range PBE functional                                            */
+#define  XC_GGA_C_LYPR                  624  /*Short-range LYP of Ai, Fang and Su                                    */
 #define  XC_GGA_K_LGAP_GE               633  /*LGAP_GE by Constantin et al                                           */
 #define  XC_GGA_K_TFVW_OPT              635  /* empirically optimized gamma-TFvW form                                */
 #define  XC_GGA_C_MGGAC                 712  /* beta fitted to LC20 to be used with MGGAC                            */
@@ -456,6 +460,7 @@
 #define  XC_HYB_MGGA_XC_EDMGGAH         695  /*Tao 2001 hybrid                                                       */
 #define  XC_HYB_MGGA_X_JS18             705  /*a screened version of TM                                              */
 #define  XC_HYB_MGGA_X_PJS18            706  /*a screened version of TM                                              */
+#define  XC_HYB_MGGA_XC_LC_TMLYP        720  /* long-range corrected TM-LYP                                          */
 #define  XC_MGGA_C_DLDF                  37  /* Dispersionless Density Functional                                    */
 #define  XC_MGGA_XC_ZLP                  42  /*Zhao, Levy & Parr, Eq. (21)                                           */
 #define  XC_MGGA_XC_OTPSS_D              64  /*oTPSS_D functional of Goerigk and Grimme                              */
@@ -555,6 +560,7 @@
 #define  XC_MGGA_K_L04                  617  /*L0.4 by Laricchia et al                                               */
 #define  XC_MGGA_K_L06                  618  /* L0.6 by Laricchia et al                                              */
 #define  XC_MGGA_K_RDA                  621  /*RDA by Karasiev et al                                                 */
+#define  XC_MGGA_X_REGTM                626  /*Regularized Tao-Mo exchange                                           */
 #define  XC_MGGA_K_GEA2                 627  /*Second-order gradient expansion                                       */
 #define  XC_MGGA_K_GEA4                 628  /*Fourth-order gradient expansion                                       */
 #define  XC_MGGA_K_CSK1                 629  /*mGGA-rev functional by Cancio, Stewart, and Kuna (a=1)                */
